searchNodes=[{"type":"module","title":"Zoneinfo","doc":"Elixir time zone support for your OS-supplied time zone database Tell Elixir to use this as the default time zone database by running: Calendar . put_time_zone_database ( Zoneinfo.TimeZoneDatabase ) Time zone data is loaded from the path returned by tzpath/0 . The default is to use /usr/share/zoneinfo , but that may be changed by setting the $TZPATH environment or adding the following to your project's config.exs : config :zoneinfo , tzpath : &quot;/custom/location&quot; Call time_zones/0 to get the list of supported time zones.","ref":"Zoneinfo.html"},{"type":"function","title":"Zoneinfo.get_metadata/1","doc":"Return Zoneinfo metadata on a time zone The returned metadata is limited to what's available in the source TZif data file for the time zone. It's mostly useful for verifying that time zone information is available for dates used in your application. Note that proper time zone calculations depend on many things and it's possible that they'll work outside of the returned ranged. However, it's also possible that a time zone database was built and then a law changed which invalidates a record.","ref":"Zoneinfo.html#get_metadata/1"},{"type":"function","title":"Zoneinfo.time_zones/0","doc":"Return all known time zones This function scans the path returned by tzpath/0 for all time zones and performs a basic check on each file. It may not be fast. It will not return the aliases that zoneinfo uses for backwards compatibility even though they may still work.","ref":"Zoneinfo.html#time_zones/0"},{"type":"function","title":"Zoneinfo.tzpath/0","doc":"Return the path to the time zone files","ref":"Zoneinfo.html#tzpath/0"},{"type":"function","title":"Zoneinfo.valid_time_zone?/1","doc":"Return whether a time zone is valid","ref":"Zoneinfo.html#valid_time_zone?/1"},{"type":"module","title":"Zoneinfo.Meta","doc":"Metadata derived from TZif information The metadata here is mostly useful for checking the quality of the TZif files that were loaded.","ref":"Zoneinfo.Meta.html"},{"type":"type","title":"Zoneinfo.Meta.t/0","doc":"Zoneinfo.Meta contains information about one time zone :time_zone - the name of the time zone :tz_string - if a POSIX TZ string is available, this is it :earliest_record_utc - the UTC time of the earliest time zone record :latest_record_utc - the UTC time of the latest time zone record :record_count -- the number of records","ref":"Zoneinfo.Meta.html#t:t/0"},{"type":"module","title":"Zoneinfo.TimeZoneDatabase","doc":"Calendar.TimeZoneDatabase implementation for Zoneinfo Pass this module to the DateTime functions: iex&gt; DateTime . now! ( &quot;Europe/Copenhagen&quot; , Zoneinfo.TimeZoneDatabase ) # DateTime &lt; 2021 - 07 - 24 12 : 56 : 38.324705 + 02 : 00 CEST Europe / Copenhagen &gt; or set it as the default by calling Calendar.put_time_zone_database/1 : iex&gt; Calendar . put_time_zone_database ( Zoneinfo.TimeZoneDatabase ) iex&gt; DateTime . now! ( &quot;Europe/Copenhagen&quot; ) # DateTime &lt; 2021 - 07 - 24 12 : 56 : 38.324705 + 02 : 00 CEST Europe / Copenhagen &gt;","ref":"Zoneinfo.TimeZoneDatabase.html"},{"type":"extras","title":"Zoneinfo","doc":"Elixir time zone support for your OS-supplied zoneinfo files Why Zoneinfo? Reuse your OS-maintained time zone database (usually in /usr/share/zoneinfo ) Reduce your OTP release size by not bundling time zone data Load other TZif files Why not Zoneinfo? tzdata and tz work fine for you You can't rely on your OS to update time zone files and don't want to implement this yourself You're running on Windows (the zoneinfo database can still be installed, but this is not a typical configuration) You need to extrapolate time zone conversions far in the future or past. Zoneinfo currently is limited to the ranges in TZif files which typically go to 2038. Speed is of utmost importance. Zoneinfo loads time zones on demand and caches them, but it does not focus on performance like tz . Zoneinfo is tested for consistency against the tz library. It's possible to test against tzdata by modifying @truth in the unit tests. All libraries source their information from the IANA Time Zone Database","ref":"readme.html"},{"type":"extras","title":"Zoneinfo - Installation","doc":"First, add :zoneinfo to your list of dependencies in mix.exs : def deps do [ { :zoneinfo , &quot;~&gt; 0.1.0&quot; } ] end Next, decide whether you want to configure Elixir to use Zoneinfo as the default time zone lookup. If you do, add the following line to your config.exs : config :elixir , time_zone_database : Zoneinfo.TimeZoneDatabase or call Calendar.put_time_zone_database/1 : Calendar . put_time_zone_database ( Zoneinfo.TimeZoneDatabase ) It's also possible to pass Zoneinfo.TimeZoneDatabase to DateTime functions to avoid the global configuration. The final step is to specify the location of the time zone files. Zoneinfo looks at the following locations: The :tzpath key in the application environment The TZPATH environment variable /usr/share/zoneinfo Since /usr/share/zoneinfo is the default on Linux and OSX, you may not need to do anything. To set :tzpath in the application environment, add this line to your config.exs : config :zoneinfo , tzpath : &quot;/custom/location&quot;","ref":"readme.html#installation"},{"type":"extras","title":"Zoneinfo - Notes and caveats","doc":"Caching While Zoneinfo does not contain a database and therefore has no logic to pull updates, it does cache data in memory for better performance. It flushes the cache daily so that it's possible to pick up changes to the system timezone data. Date ranges Zoneinfo uses the date ranges stored in the TZif data for determining time zone information. While TZif files support extrapolation of dates beyond what's stored, Zoneinfo currently does not use it. This means that dates far enough in the future won't be calculated correctly. The default end date from the time zone compiler, zic(8) , is 2038. This could, of course, could change and one would hope that it would be pushed farther out rather than reduced since the files are already pretty small. If you're looking at creating the smallest possible time zone database for and embedded system, using zic 's -r flag helps significantly, but make sure that you have enough buffer to avoid extrapolation. Unit tests The tests currently take a long time to run since they're checking a LOT of dates and times. If you're working on a patch, you may want to limit the date range in time_zone_database_test.exs to 10 years or less.","ref":"readme.html#notes-and-caveats"},{"type":"extras","title":"Zoneinfo - Acknowledgments","doc":"Both tz and tzdata were both extremely helpful in answering time zone questions. Code in this library will almost certainly look like it was influenced from the two libraries. Additionally, being able to compare the output of Zoneinfo to the output of those libraries caught a few subtle time zone handling bugs that could easily have gone unnoticed. The IANA time zone rules database comments and timeanddate.com were also extremely helpful to resolve discrepancies.","ref":"readme.html#acknowledgments"},{"type":"extras","title":"Zoneinfo - License","doc":"Copyright (C) 2021 SmartRent.com, LLC Licensed under the Apache License , Version 2.0 ( the &quot;License&quot; ) ; you may not use this file except in compliance with the License . You may obtain a copy of the License at [ http :// www . apache . org / licenses / LICENSE - 2.0 ] ( http :// www . apache . org / licenses / LICENSE - 2.0 ) Unless required by applicable law or agreed to in writing , software distributed under the License is distributed on an &quot;AS IS&quot; BASIS , WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND , either express or implied . See the License for the specific language governing permissions and limitations under the License .","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"","ref":"changelog.html"},{"type":"extras","title":"Changelog - v0.1.6","doc":"Improvements Fix warnings when building on Elixir 1.15 Improve testing","ref":"changelog.html#v0-1-6"},{"type":"extras","title":"Changelog - v0.1.5","doc":"Improvements Fix Calendar return values when time zone queries are wrong. Thanks to @LostKobrakai for this fix.","ref":"changelog.html#v0-1-5"},{"type":"extras","title":"Changelog - v0.1.4","doc":"Improvements Updated documentation thanks to Wojtek Mach.","ref":"changelog.html#v0-1-4"},{"type":"extras","title":"Changelog - v0.1.3","doc":"Improvements UTC and standard time offsets are now tested for consistency with Tz. Normally you just want the overall offset from UTC and that was already tested (this is what's used in the DateTime calculations). The TZif data doesn't split out the offsets, but it turned out that a heuristic works really well. Unit tests run quickly. Thorough tests are available via mix test --include slow Bug fixes Fixed UTC and standard time offsets discrepancies with Tz (and hence the IANA rules database). The only known exceptions now are Paris and Monoco in the mid-1940s and Morocco. See the unit tests for discussion on the differences.","ref":"changelog.html#v0-1-3"},{"type":"extras","title":"Changelog - v0.1.2","doc":"New features Add Zoneinfo.get_metadata/1 to expose diagnostic information useful for sanity checking date ranges available on a system","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"Changelog - v0.1.1","doc":"New features Add Zoneinfo.valid_time_zone?/1 to quickly check if a time zone is in the database","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"Changelog - v0.1.0","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}]